/*
 * Copyright 2022 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "wTDirichlet.h"
#include "wProblem.h"
#include "wTag.h"
#include "wElement.h"
#include "wNode.h"
//#include <algorithm>
using namespace mirrors;

TDirichlet::TDirichlet(mirrors::Problem &pbl, int no, std::string _BC_name, double _values) : Group(pbl.msh, no), BC_name(_BC_name), values(_values)
{
    for (auto e : tag->elems)
        for (auto n : e->nodes)
            nodes.push_back(n);

    pbl.dTBCs.push_back(this);
}

TDirichlet::TDirichlet(mirrors::Problem &pbl, std::string const &name, std::string _BC_name, double _values) : Group(pbl.msh, name), BC_name(_BC_name), values(_values)
{
    for (auto e : tag->elems)
        for (auto n : e->nodes)
            nodes.push_back(n);

    pbl.dTBCs.push_back(this);
}

void TDirichlet::write(std::ostream &out) const
{
    out << "Thermal Dirichlet BC named ''" << BC_name << "'' on " << *tag << "\n";
    out << "With fixed temperature of :";
    out << values << " .\n";
    for (auto n : nodes)
    {
        out << '\t' << *n << '\n';
    }
}
