/*
 * Copyright 2022 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef WTHERMOMECATERM_H
#define WTHERMOMECATERM_H

#include "mirrors.h"

#include <vector>
#include <Eigen/Dense>

namespace mirrors
{

/**
 * @brief Formulation of thermo-mechanical terms
 */
class MIRRORS_API ThermoMecaTerm
{
public:
    // Mass matrix
    static Eigen::MatrixXd buildM(tbox::Element const &e);
    // Thermo-mechanical matrices
    static Eigen::MatrixXd buildK(tbox::Element const &e, Eigen::MatrixXd const &H);
    static Eigen::MatrixXd buildL(tbox::Element const &e, Eigen::MatrixXd const &C);
    static Eigen::MatrixXd buildS(tbox::Element const &e, Eigen::MatrixXd const &D);
    // Strain/stress computation
    static void strain_stress(tbox::Element const &e, Eigen::MatrixXd const &H, std::vector<double> const &u, Eigen::MatrixXd &Strain, Eigen::MatrixXd &Stress);
};

} // namespace mirrors
#endif //WTHERMOMECATERM_H
